summaryrefslogtreecommitdiff
path: root/rust/src/architecture.rs
diff options
context:
space:
mode:
Diffstat (limited to 'rust/src/architecture.rs')
-rw-r--r--rust/src/architecture.rs4
1 files changed, 2 insertions, 2 deletions
diff --git a/rust/src/architecture.rs b/rust/src/architecture.rs
index 857a6e88..997089f8 100644
--- a/rust/src/architecture.rs
+++ b/rust/src/architecture.rs
@@ -305,7 +305,7 @@ pub trait RegisterStackInfo: Sized {
fn stack_top_reg(&self) -> Self::RegType;
}
-pub trait RegisterStack: Sized + Clone + Copy {
+pub trait RegisterStack: Debug + Sized + Clone + Copy {
type InfoType: RegisterStackInfo<
RegType = Self::RegType,
RegInfoType = Self::RegInfoType,
@@ -641,7 +641,7 @@ pub struct UnusedRegisterStackInfo<R: Register> {
_reg: std::marker::PhantomData<R>,
}
#[derive(Clone, Copy, PartialEq, Eq, Hash)]
pub struct UnusedRegisterStack<R: Register> {
_reg: std::marker::PhantomData<R>,
}
@@ -641,7 +641,7 @@ pub struct UnusedRegisterStackInfo<R: Register> {
_reg: std::marker::PhantomData<R>,
}
-#[derive(Clone, Copy, PartialEq, Eq, Hash)]
+#[derive(Debug, Clone, Copy, PartialEq, Eq, Hash)]
pub struct UnusedRegisterStack<R: Register> {
_reg: std::marker::PhantomData<R>,